Crate imperat

Crate imperat 

Modules

prelude

Structs

Dep
A dependency which can be automatically resolved at runtime by its unique type.
ImperativeStepBuilder
A builder which returns an output O on execution. Create one by calling new.
TypeMap
Nearly 1-to-1 with this blog: https://nickbryan.co.uk/software/using-a-type-map-for-dependency-injection-in-rust/ A TypeMap uniquely stores an arbitrary value by its type. No types can store more than one value.

Enums

BuilderError

Traits

Callable
Something that is callable with a specific interface.
FromTypeMap
A type which can be retrieved from a type map. Its type signature uniquely stores the type in the map.
IntoStepOutcome
All step functions must return a result with a result that dictates step outcome.

Functions

new_builder
The primary entrypoint to building out an imperative runner. Initialize with default and then chain calls to each other.

Derive Macros

Dependency