Modules
Structs
- Dep
- A dependency which can be automatically resolved at runtime by its unique type.
- Imperative
Step Builder - A builder which returns an output
Oon execution. Create one by callingnew. - TypeMap
- Nearly 1-to-1 with this blog:
https://nickbryan.co.uk/software/using-a-type-map-for-dependency-injection-in-rust/
A
TypeMapuniquely stores an arbitrary value by its type. No types can store more than one value.
Enums
Traits
- Callable
- Something that is callable with a specific interface.
- From
Type Map - A type which can be retrieved from a type map. Its type signature uniquely stores the type in the map.
- Into
Step Outcome - All step functions must return a result with a result that dictates step outcome.
Functions
- new_
builder - The primary entrypoint to building out an imperative runner. Initialize with default and then chain calls to each other.